use vulkano_util::renderer::VulkanoWindowRenderer;

use super::{input::InputState, render::vulkan_context::VulkanContext, timer::Timer};

pub trait Scene {
    fn load(&mut self, app: &mut App);
    fn update(&mut self, app: &mut App);
    fn render(&self);
    fn unload(&mut self);
}

pub struct SceneManager {
    current_scene: Option<Box<dyn Scene>>,
}

impl SceneManager {
    pub fn new() -> Self {
        Self {
            current_scene: None,
        }
    }

    pub fn load_scene(&mut self, scene: Box<dyn Scene>) {
        if let Some(current_scene) = self.current_scene.as_mut() {
            current_scene.unload();
        }
        self.current_scene = Some(scene);
    }
}
